@@ -46,25 +46,56 @@ feed.loadFriendsFeed = function(page, history) {
 feed.parseFriendsFeedUpdate = function(response, page) {
     var data = api.process(response, page);
     feed.debug(function(){return "UPDATES: " + JSON.stringify(data)});
-    data.updates.items.forEach(
-        function(update){
-            if (update.type === "checkin") {
-                for (var i=0;i<page.friendsCheckinsModel.count;i++) {
-                    var info = page.friendsCheckinsModel.get(i).content;
-                    if (info.id !== update.id)
-                        continue;
-                    feed.log("FOUND CHECKIN in MODEL: " + update.id);
-                    info.commentsCount = update.comments.count;
-                    info.comments = update.comments.items;
-                    info.likesCount = update.likes.count;
-                    page.updateItem(i,info);
-                    break;
-                }
-            } else {
-                feed.log("UPDATE TYPE: " + update.type);
-                feed.log("UPDATE CONTENT: " + JSON.stringify(update));
+
+    for(var prop in data) {
+        if (prop === "updates") {
+            data.updates.items.forEach(
+                function(update){
+                    if (update.type === "checkin") {
+                        for (var i=0;i<page.friendsCheckinsModel.count;i++) {
+                            var info = page.friendsCheckinsModel.get(i).content;
+                            if (info.id !== update.id)
+                                continue;
+                            feed.log("FOUND CHECKIN in MODEL: " + update.id);
+                            info.commentsCount = update.comments.count;
+                            info.comments = update.comments.items;
+                            info.likesCount = update.likes.count;
+                            page.updateItem(i,info);
+                            break;
+                        }
+                    } else {
+                        feed.log("UPDATE FEED TYPE: " + update.type);
+                        feed.debug(function(){ return "UPDATE CONTENT: " + JSON.stringify(update)});
+                        var updateitem = {
+                            "type": "feed-update",
+                            "content": update
+                        }
+                        page.addItem(updateitem,0);
+                    }
+                });
+        } else if (prop === "deletes") {
+            data.deletes.items.forEach(
+                function(del) {
+                    feed.log("UPDATE FEED TYPE: " + del.type);
+                    feed.debug(function(){ return "UPDATE CONTENT: " + JSON.stringify(del)});
+                    var deleteitem = {
+                        "type": "feed-delete",
+                        "content": del
+                    }
+                    page.addItem(deleteitem,0);
+                });
+        } else {
+            feed.log("UPDATE TYPE: " + prop);
+            var propdata = data[prop];
+            if (propdata.type === undefined)
+                propdata.type = "feed-" + prop
+            var propitem = {
+                "type": "feed-" + prop,
+                "content": propdata
             }
-        });
+            page.addItem(propitem,0);
+        }
+    }
 }
 
 feed.parseFriendsFeed = function(response, page, history) {
@@ -73,14 +104,9 @@ feed.parseFriendsFeed = function(response, page, history) {
     var data = api.process(response, page);
     var activities = data.activities;
 
-    var count = 0;
     var updateTime = page.lastUpdateTime;
     var updating = (updateTime !== "0");
 
-    if (page.leadingMarker === "") {
-        page.friendsCheckinsModel.clear();
-    }
-
     if (history !== undefined || !updating) {
         feed.debug(function(){return"MORE DATA: Updated: "+ activities.moreData});
         page.moreData = activities.moreData;
@@ -93,7 +119,6 @@ feed.parseFriendsFeed = function(response, page, history) {
     var feedObjParser = function(object) {
         //DBG
         //object = loaddebugobject();
-        var append = (!updating || history!==undefined);
         var timeObj = object;
         if (timeObj.object !== undefined) {
             timeObj=timeObj.object;
@@ -105,17 +130,14 @@ feed.parseFriendsFeed = function(response, page, history) {
         if (object.type === "create") {
             var create = object.content;
             if (create.type === "checkin") {
-                if (feed.feedObjParserCheckin(page, object, append, count))
-                    count++;
+                feed.feedObjParserCheckin(page, object);
             } else if (create.type === "photo") {
                 feed.feedObjParserPhoto(page,object);
             } else if (create.type === "tip") {
                 object.content.summary = object.summary;
-                feed.feedObjParserTip(page, object, append, count);
-                count++;
+                feed.feedObjParserTip(page, object);
             } else if (create.type === "pageUpdate") {
-                feed.feedObjParserPageUpdate(page, object, append, count);
-                count++;
+                feed.feedObjParserPageUpdate(page, object);
             } else if (create.type === "aggregation"){
                 object.content.object.items.forEach(function(item) {
                     object.content = item;
@@ -125,22 +147,17 @@ feed.parseFriendsFeed = function(response, page, history) {
                 feed.log("CREATE TYPE: " + create.type);
                 feed.debug(function(){return "CREATE VALUE: " + JSON.stringify(object)});
                 feed.feedObjParserUnknown(page, object);
-                count++;
             }
         } else if (object.type === "like") {
             var like = object.content;
             if (like.type === "tip") {
-                feed.feedObjParserLikeTip(page, object, append, count);
-                count++;
+                feed.feedObjParserLikeTip(page, object);
             } else if (like.type === "venue") {
-                feed.feedObjParserLikeVenue(page, object, append, count);
-                count++;
+                feed.feedObjParserLikeVenue(page, object);
             } else if (like.type === "page") {
-                feed.feedObjParserLikePage(page, object, append, count);
-                count++;
+                feed.feedObjParserLikePage(page, object);
             } else if (like.type === "pageUpdate") {
-                feed.feedObjParserLikePageUpdate(page, object, append, count);
-                count++;
+                feed.feedObjParserLikePageUpdate(page, object);
             } else if (like.type === "aggregation"){
                 object.content.object.items.forEach(function(item) {
                     object.content = item;
@@ -150,25 +167,20 @@ feed.parseFriendsFeed = function(response, page, history) {
                 feed.log("LIKE TYPE: " + like.type);
                 feed.debug(function(){return "LIKE VALUE: " + JSON.stringify(object)});
                 feed.feedObjParserUnknown(page, object);
-                count++;
             }
         } else if (object.type === "save") {
             var save = object.content;
             if (save.type === "activity") {
                 if (save.object.content.type === "list") {
-                    feed.feedObjParserSaveList(page, object, append, count);
-                    count++;
+                    feed.feedObjParserSaveList(page, object);
                 } else if (save.object.content.type === "venue") {
-                    feed.feedObjParserSaveVenue(page, object, append, count);
-                    count++;
+                    feed.feedObjParserSaveVenue(page, object);
                 } else if (save.object.content.type === "tip") {
-                    feed.feedObjParserSaveTip(page, object, append, count);
-                    count++;
+                    feed.feedObjParserSaveTip(page, object);
                 } else {
                     feed.log("SAVE TYPE: " + save.type + " OBJECT: " + save.object.content.type);
                     feed.debug(function(){return "SAVE VALUE: " + JSON.stringify(object)});
                     feed.feedObjParserUnknown(page, object);
-                    count++;
                 }
             } else if (save.type === "aggregation"){
                 object.content.object.items.forEach(function(item) {
@@ -179,39 +191,32 @@ feed.parseFriendsFeed = function(response, page, history) {
                 feed.log("SAVE TYPE: " + save.type);
                 feed.debug(function(){return "SAVE VALUE: " + JSON.stringify(object)});
                 feed.feedObjParserUnknown(page, object);
-                count++;
             }
         } else if (object.type === "install") {
             var install = object.content;
             if (install.type === "plugin") {
-                feed.feedObjParserInstallPlugin(page, object, append, count);
-                count++;
+                feed.feedObjParserInstallPlugin(page, object);
             } else {
                 feed.log("INSTALL TYPE: " + install.type);
                 feed.debug(function(){return "SAVE VALUE: " + JSON.stringify(object)});
                 feed.feedObjParserUnknown(page, object);
-                count++;
             }
         } else if (object.type === "award") {
             var award = object.content;
             if (award.type === "badge") {
-                feed.feedObjParserAwardBadge(page, object, append, count);
-                count++;
+                feed.feedObjParserAwardBadge(page, object);
             } else {
                 feed.log("AWARD TYPE: " + award.type);
                 feed.debug(function(){return "SAVE VALUE: " + JSON.stringify(object)});
                 feed.feedObjParserUnknown(page, object);
-                count++;
             }
         } else if (object.type === "friend" ) {
-            feed.feedObjParserFriend(page, object, append, count);
-            count++;
+            feed.feedObjParserFriend(page, object);
         } else {
             //un implemented content types goes here
             feed.log("CONTENT TYPE: " + object.type);
             feed.debug(function(){return "CONTENT VALUE: " + JSON.stringify(object)});
             feed.feedObjParserUnknown(page, object);
-            count++;
         }
     }
 
@@ -249,9 +254,8 @@ feed.feedObjParserUnknown = function(page, object) {
     page.addItem(item);
 }
 
-feed.feedObjParserCheckin = function(page, object, append, count) {
+feed.feedObjParserCheckin = function(page, object) {
     var checkin = object.content.object;
-    var result = true;
     var userName = makeUserName(checkin.user);
     var venueName = "";
     var venueID = "";
@@ -286,18 +290,10 @@ feed.feedObjParserCheckin = function(page, object, append, count) {
                 "photosCount": checkin.photos.count
             }
         };
-        if (append) {
-            feed.debug(function(){return "adding checkin at end"});
-            page.addItem(item);
-        } else {
-            page.addItem(item,count);
-            feed.debug(function(){return "adding checkin at head"});
-        }
-        result = true;
+        page.addItem(item);
     } else if (venueDistance !== undefined) {
-        result = false;
+        //event is not nearby;
     }
-    return result;
 }
 
 feed.feedObjParserPhoto = function(page, object) {
@@ -315,7 +311,7 @@ feed.feedObjParserPhoto = function(page, object) {
     }
 }
 
-feed.feedObjParserFriend = function(page, friend, append, count) {
+feed.feedObjParserFriend = function(page, friend) {
     if (friend.content.type === "aggregation") {
         //TODO: change if aggregation will be enabled
         feed.log("FRIEND AGGREGATION!")
@@ -332,16 +328,10 @@ feed.feedObjParserFriend = function(page, friend, append, count) {
             "timestamp": friend.createdAt,
         }
     };
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        page.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        page.addItem(item,count);
-    }
+    page.addItem(item);
 }
 
-feed.feedObjParserTip = function(page, object, append, count) {
+feed.feedObjParserTip = function(page, object) {
     var tip = object.content.object;
     feed.debug(function(){return "TIP CONTENT: " + JSON.stringify(object)});
     var icon = "";
@@ -364,16 +354,10 @@ feed.feedObjParserTip = function(page, object, append, count) {
             "timestamp": tip.createdAt,
         }
     }
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        page.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        page.addItem(item,count);
-    }
+    page.addItem(item);
 }
 
-feed.feedObjParserLikeTip = function(page, object, append, count) {
+feed.feedObjParserLikeTip = function(page, object) {
     var tip = object.content.object;
     feed.debug(function(){return "LIKE TIP CONTENT: " + JSON.stringify(object)});
     var icon = "";
@@ -396,16 +380,10 @@ feed.feedObjParserLikeTip = function(page, object, append, count) {
             "timestamp": object.createdAt,
         }
     }
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        page.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        page.addItem(item,count);
-    }
+    page.addItem(item);
 };
 
-feed.feedObjParserLikePage = function(owner, object, append, count) {
+feed.feedObjParserLikePage = function(owner, object) {
     var page = object.content.object
     var item = {
         "type": "likepage",
@@ -422,21 +400,15 @@ feed.feedObjParserLikePage = function(owner, object, append, count) {
             "timestamp": object.createdAt,
         }
     }
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        owner.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        owner.addItem(item,count);
-    }
+    owner.addItem(item);
 }
 
-feed.feedObjParserLikePageUpdate = function(owner, object, append, count) {
+feed.feedObjParserLikePageUpdate = function(owner, object) {
     //TODO: likepageupdate
-    feed.feedObjParserPageUpdate(owner, object, append, count);
+    feed.feedObjParserPageUpdate(owner, object);
 }
 
-feed.feedObjParserPageUpdate = function(owner, object, append, count) {
+feed.feedObjParserPageUpdate = function(owner, object) {
     var pageupdate = object.content.object;
 
     var venuePhoto = "";
@@ -461,16 +433,10 @@ feed.feedObjParserPageUpdate = function(owner, object, append, count) {
             "timestamp": object.createdAt,
         }
     }
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        owner.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        owner.addItem(item,count);
-    }
+    owner.addItem(item);
 }
 
-feed.feedObjParserAwardBadge = function(page, object, append, count) {
+feed.feedObjParserAwardBadge = function(page, object) {
     var badge = object.content.object;
     feed.debug(function(){return "AWARD BADGE CONTENT: " + JSON.stringify(object)});
     var item = {
@@ -486,16 +452,10 @@ feed.feedObjParserAwardBadge = function(page, object, append, count) {
             "timestamp": object.createdAt,
         }
     }
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        page.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        page.addItem(item,count);
-    }
+    page.addItem(item);
 }
 
-feed.feedObjParserLikeVenue = function(page, object, append, count) {
+feed.feedObjParserLikeVenue = function(page, object) {
     var venue = object.content.object;
     feed.debug(function(){return "LIKE VENUE CONTENT: " + JSON.stringify(object)});
     var icon = "";
@@ -516,16 +476,10 @@ feed.feedObjParserLikeVenue = function(page, object, append, count) {
             "timestamp": object.createdAt,
         }
     }
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        page.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        page.addItem(item,count);
-    }
+    page.addItem(item);
 };
 
-feed.feedObjParserSaveTip = function(page, object, append, count) {
+feed.feedObjParserSaveTip = function(page, object) {
     var tip = object.content.object.content.object;
     feed.debug(function(){return "SAVE TIP CONTENT: " + JSON.stringify(object)});
     var icon = "";
@@ -548,16 +502,10 @@ feed.feedObjParserSaveTip = function(page, object, append, count) {
             "timestamp": object.createdAt,
         }
     }
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        page.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        page.addItem(item,count);
-    }
+    page.addItem(item);
 };
 
-feed.feedObjParserSaveList = function (page, object, append, count) {
+feed.feedObjParserSaveList = function (page, object) {
     var list = object.content.object.content.object;
     feed.debug(function(){return "LIST: " + JSON.stringify(list)});
     var item = {
@@ -574,16 +522,10 @@ feed.feedObjParserSaveList = function (page, object, append, count) {
             "timestamp": object.createdAt,
         }
     }
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        page.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        page.addItem(item,count);
-    }
+    page.addItem(item);
 }
 
-feed.feedObjParserSaveVenue = function (page, object, append, count) {
+feed.feedObjParserSaveVenue = function (page, object) {
     var venue = object.content.object.content.object;
     feed.debug(function(){return "SAVE VENUE CONTENT: " + JSON.stringify(object.content.object)});
     var icon = "";
@@ -604,16 +546,10 @@ feed.feedObjParserSaveVenue = function (page, object, append, count) {
             "timestamp": object.createdAt,
         }
     }
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        page.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        page.addItem(item,count);
-    }
+    page.addItem(item);
 }
 
-feed.feedObjParserInstallPlugin = function(page, object, append, count) {
+feed.feedObjParserInstallPlugin = function(page, object) {
     var plugin = object.content.object;
     feed.debug(function(){return "PLUGIN: " + JSON.stringify(plugin)});
     var item = {
@@ -630,11 +566,5 @@ feed.feedObjParserInstallPlugin = function(page, object, append, count) {
             "timestamp": object.createdAt,
         }
     };
-    if (append) {
-        feed.debug(function(){return "adding friend at end"});
-        page.addItem(item);
-    } else {
-        feed.debug(function(){return "adding friend at head"});
-        page.addItem(item,count);
-    }
+    page.addItem(item);
 }
